%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
%
%                 FAST FOURIER TRANSFORM 
%
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Last updated : Apr. 04
% By Erol Kalkan
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
clear;clc;
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
load rec_ch15.tcl;
accel=rec_ch15;
dt=0.01;
bt=20;  %Bracket duration in second 
td=50; %Total duration
ti=5;   %Time interval for shifting
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Building modal periods;
T=[3.56
    3.34
    1.24
    1.124
    0.75
    0.59];
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Computation of frequency
[s1 s2]=size(T);
for jj=1:s1;
    F(jj)=1/T(jj);
end

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
nw=1+(td-bt)/ti; % Number of windows 

for i=0:nw;
 clear P; clear data_filt;
 clear filtre;
     if i==0
        b1=0;
        b2=td;
        
    else 
        b1=(i-1)*ti;
        b2=b1+bt;
    end
        b2=b2/dt; b1=b1/dt;
        acc=accel((b1+1):b2);   
[N,b]=size(acc);


[freq, faplota]=fourier(acc,dt);

% BUTTERWORTH LOWPASS FILTERing ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
fc=1/T(6);
order=18;

[d1 d2]=size(freq);

for z=1:d2;
    filtre(z)=1/(1+(fc/freq(z))^(-2*order))^0.5; % FOR HIGH PASS TAKE +2*order
    data_filt(z)=filtre(z)*faplota(z);
end
faplota=data_filt;

%[faplota]=butterworth(faplota,freq,fc,Order);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% X-axis = Frequency
figure(1);
subplot(nw+1,1,i+1);
plot(freq,faplota./N,F(1),[0:max(faplota./N)/100:max(faplota./N)],'r',F(2),[0:max(faplota./N)/100:max(faplota./N)],'r',F(3),[0:max(faplota./N)/100:max(faplota./N)],'r',F(4),[0:max(faplota./N)/100:max(faplota./N)],'r',F(5),[0:max(faplota./N)/100:max(faplota./N)],'r',F(6),[0:max(faplota./N)/100:max(faplota./N)],'r');% Plot normalized Fourier Spectra
xlabel('Frequecy (Hz)');
ylabel('FAA');
axis([0 3 0 max(faplota./N)]); grid;
hold;
% Plot normalized polynomial Fourier Spectra
%plot(freq,y);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Compute period as x-axis
[a b]=size(freq);
for ii=1:b;
    P(ii)=1/freq(ii);
end

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% X-axis = Period
figure(2);
subplot(nw+1,1,i+1);
plot(P,faplota./N,T(1),[0:max(faplota./N)/100:max(faplota./N)],'r',T(2),[0:max(faplota./N)/100:max(faplota./N)],'r',T(3),[0:max(faplota./N)/100:max(faplota./N)],'r')
hold
plot(T(4),[0:max(faplota./N)/100:max(faplota./N)],'r',T(5),[0:max(faplota./N)/100:max(faplota./N)],'r',T(6),[0:max(faplota./N)/100:max(faplota./N)],'r');% Plot normalized Fourier Spectra
xlabel('Period (sec)');
ylabel('FAA');
axis([0 5 0 max(faplota./N)]); grid;
hold;
end

figure(3)
plot(P,filtre,T(5),[0:1/d2:1],'r')
xlabel('Period (sec)');
ylabel('Filter Amplitude');
hold
axis([0 5 0 1]);
title('Butterworth Lowpass Filter')






