%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%
%            RALEIGH DAMPING EVALUATIN SUBROUTINE
%
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%
% Last updated : 04/01/04
% By : Erol Kalkan
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
clear;clc;

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Select the modes in Raleigh damping;
i=1; %First mode
j=3; %Third mode

% Select the damping ratio for two of the selected modes;
s=[0.02
   0.03];

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Enter period vector
T=[3.56
    3.34
    1.24
    1.124
    0.750];
[n b]=size(T);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Cyclic frequency computation
for ii=1:n;
    w(ii)=2*pi/T(ii);
end

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Frequency computation
for ii=1:n;
    f(ii)=1/T(ii);
end

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Raleigh coefficients computations, ao and a1;

A=[1/w(i) w(i)
    1/w(j) w(j)];

a=2*inv(A)*s;
ao=a(1)
a1=a(2)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Computation of damping for each mode

for k=1:n
    S(k)=a(1)/2*1/w(k)+a(2)/2*w(k);
end
Modal_Damping=S
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Plotting Raleigh Damping

ww=w(1)/2:w(n)/100:w(n)*2;
[x q]=size(ww);
for m=1:q;
    SS(m)=a(1)/2/ww(m)+a(2)*ww(m)/2;
end

% Straight Line setup for w1 and w2
line_w1=LINSPACE(w(i),w(i),q);
line_s1=LINSPACE(0,s(1),q); 
line_w2=LINSPACE(w(j),w(j),q); 
line_s2=LINSPACE(0,s(2),q);
hor_line1=LINSPACE(s(1),s(1),q);
ver_line1=LINSPACE(0,w(i),q);
hor_line2=LINSPACE(s(2),s(2),q);
ver_line2=LINSPACE(0,w(j),q);

plot(ww,SS,line_w1,line_s1,':r',line_w2,line_s2,':r',ver_line1,hor_line1,':r',ver_line2,hor_line2,':r')
hold
for v=1:n;
    plot(w(v),S(v),'o');
end
axis([0,10,0,0.1]);
xlabel('Natural Frequency, wn');ylabel('Modal Damping Ratio');
title('Raleigh Damping Plot');

