%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
%
%                 FAST FOURIER TRANSFORM 
%
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Last updated : Apr. 04
% By Erol Kalkan
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
load rec_ch15.tcl;
accel=rec_ch15;
dt=0.01;
b1=0; %First bracket time in second
b2=100;%Last bracket time in second

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Building modal periods;
T=[4.28
    3.34
    1.40
    1.238
    0.7785];

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
b2=b2/dt;
acc=accel((b1+1):1:b2);   
[N,b]=size(acc);

fta=fft(acc,N);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Compute fourier amplitude
faa=abs(fta);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Determine frequency step and generate frequency axis from deltaf to
% Nyquist frequency
deltaf=1/(N*dt);
freq=deltaf*(1:N/2);
[a b]=size(freq);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Extract first half of the fourier amplitude
faplota=faa(1:N/2);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Polynomial fit to normalized fourier amplitude spectrum of acceleration
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
p=polyfit(freq',faplota./N,10);
y=polyval(p,freq);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% plot the smoothed spectrum alone and overlaid with the actual spectrum
subplot(2,1,1);
plot(freq,faplota./N);% Plot normalized Fourier Spectra
xlabel('Frequecy (Hz)');
ylabel('Fourier Amp. of Acceleration');
axis([0 6 0 max(faplota./N)]); grid;
hold;
% Plot normalized polynomial Fourier Spectra
%plot(freq,y);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
% Compute period as x-axis
for i=1:b;
    P(i)=1/freq(i);
end

subplot(2,1,2);
plot(P,faplota./N);
xlabel('Period (sec)');
ylabel('Fourier Amp. of Acceleration');
axis([0 6 0 max(faplota./N)]); grid;






