# WsectionL.tcl: tcl procedure for creating a L-shape steel fiber section
# written: Erol Kalkan
# date: 03/04

proc wsectionL { secID matID t3 t2 tf tw nfdw nftw nfbf nftf} {
  # input parameters
  # secID - section ID number
  # matID - material ID number 
  # t3  = outside vertical leg
  # t2 = outside horizontal leg
  # tf = horizontal leg thickness
  # tw = vertical leg thickness
  # nfdw = number of fibers along vertical leg
  # nftw = number of fibers along thickness of vertical leg

  # nftf = number of fibers along horizontal leg
  # nfbf = number of fibers along thickness of horizontal leg
  
  set a1 [expr $t3*$tw]
  set a2 [expr ($t2-$tw)*$tf]

  set yy [expr ($a1*$t3/2+$a2*$tf/2)/($a1+$a2)]
  set zz [expr ($a1*$tw/2+$a2*($t2-($t2-$tw)/2))/($a1+$a2)]

  set y1 [expr $t3-$yy]
  set y2 [expr -1*$yy]
  set y3 [expr -$yy+$tf]


  set z1 [expr $t2-$zz]
  set z2 [expr -1*$zz]
  set z3 [expr -$zz+$tw]

  
  #                           
  section fiberSec  $secID  {
     #                     nfIJ  nfJK    yI  zI    yJ  zJ    yK  zK    yL  zL
     patch quadr  $matID  $nftw $nfdw   $y2 $z3   $y2 $z2   $y1 $z2   $y1 $z3
     patch quadr  $matID  $nfbf $nftf   $y2 $z1   $y2 $z3   $y3 $z3   $y3 $z1
  }
}












